package PureMessage::Manager::Response::Reports::Utils;

###############################################################################
# Required inclusions.
###############################################################################
use strict;
use base qw(Exporter);
our @EXPORT_OK = qw(
    CHART_CGI
    REPORTS_CGI
    _mk_query_string
    _mk_html_chart
    _mk_single_html_chart
    );

use constant CHART_CGI   => '/Reports/chart.cgi';
use constant REPORTS_CGI => '/Reports/index.cgi';

use PureMessage::Reports::DB;
use PureMessage::Reports::Report::Config qw(%reports_config);
use HTML::Entities;

###############################################################################
# Turns the provided arguments into a CGI query string.
###############################################################################
sub _mk_query_string
{
    my (%args) = @_;
    my @fields = map { "$_=$args{$_}" } sort keys %args;
    return join( '&', @fields );
}

###############################################################################
# Returns the HTML required to show the report as a graph.
###############################################################################
sub _mk_single_html_chart
{
    my ($report, %args) = @_;

    ###########################################################################
    # Figure out if we're supposed to include a legend or not.
    ###########################################################################
    my $showlegend = delete $args{'showlegend'};

    ###########################################################################
    # Run the report, so we can be sure that the legend is correct (as it may
    # be based in part on data in the report).
    ###########################################################################
    delete $args{per_host};
    $report->run_report( %args );

    ###########################################################################
    # Use h/w here, but don't pass through when user clicks on report.
    ###########################################################################

    ###########################################################################
    # Convert the provided args into a CGI query string.
    ###########################################################################
    my $query = _mk_query_string( %args, 'v' => 'report' );

    ###########################################################################
    # Build up links to click to generate the graph and to show the graph
    # image.
    ###########################################################################
    my $href_image = CHART_CGI   . '?' . _mk_query_string( %args, 'v' => 'report' );
    my $width  = delete $args{'width'};
    my $height = delete $args{'height'};

    my $href_graph = REPORTS_CGI . '?' . _mk_query_string( %args, 'v' => 'report' );

    ###########################################################################
    # Encode href_graph and href_image to prevent XSS
    ###########################################################################
    $href_graph = encode_entities($href_graph,'&<>"\/\'');
    $href_image = encode_entities($href_image,'&<>"\/\'');

    ###########################################################################
    # Generate the HTML and return it to the caller.
    ###########################################################################
    my $title  = $report->get_title();
    my $legend = '';
    if ($showlegend && $report->has_data())
    {
        $legend = '<td>' . $report->get_legend() . '</td>';
    }

    my $html = qq{
<table>
  <tr valign="top">
    <td>
      <a href="$href_graph">
        <img border="0" src="$href_image" alt="$title">
      </a>
    </td>
    $legend
  </tr>
</table>
};
    return $html;
}

sub _mk_html_chart {
    my($report, %args) = @_;
    
    if($args{per_host}) {
        my($hosts);
        my $dbh = get_dbh;
        if($hosts = $dbh->selectall_arrayref(
            "SELECT id, name FROM prd_pmx_host ORDER BY name",
            { Slice => {} }
        )) {
            my (@rv);
            my $i = 0;
            foreach my $host (@$hosts) {
                $i++;
                push(@rv,
                    qq|<p id="fqdn_host$i"><b>$host->{name}:</b></p>|,
                    _mk_single_html_chart(
                        $report, %args, host_id => $host->{id}
                    ),
                    "<br/>"
                );
            }
            return join("\n", @rv);
        } else {
            die "Querying host list failed: ", $dbh->errstr;
        }
    } else {
        return _mk_single_html_chart($report, %args);
    }
}

1;
