package PureMessage::Reports::Report::Format::tbl;

###############################################################################
# Required inclusions.
###############################################################################
use strict;
use base qw(PureMessage::Reports::Report::Format);

###############################################################################
# Returns the MIME-Type of the formatted output.
###############################################################################
sub mime_type { return 'text/html' };

###############################################################################
# Formats the report data as an HTML Table.
###############################################################################
sub format
{
    my ($self, $data, %opts) = @_;
    my @rows;

    ###########################################################################
    # Grab relevant options.
    ###########################################################################
    my $HREF    = $opts{'more_href'};
    my $LABELS  = $opts{'labels'};
    my $numcols = scalar( @{$LABELS} );

    ###########################################################################
    # Table header.
    ###########################################################################
    {
        my @cols;
        foreach my $col (@{$LABELS})
        {
            push( @cols, qq{<td class="tableHeader" nowrap="nowrap">$col</td>} );
        }
        push( @rows, "<tr>", join('',@cols) . "</tr>\n" );
    }

    ###########################################################################
    # Put all of the data into HTML table cells
    ###########################################################################
    foreach my $row (@{$data})
    {
        # Build up all of the columns for this row.
        my @cols;
        foreach my $col (@{$row})
        {
            # If 'col' is a float remove everything after the second digit 
            # following the decimal point ie 25.23XXXXX
            # If the values on the right of the point are just zero
            # ie 25.00, remove EVERYTHING after the decimal point.

	    if ( ($col =~ /^[+-]?[0-9]+\.[0-9]+$/ ) ) {
		$col = sprintf ( "%.2f", $col );      
		if ( $col == int($col) ) {            
		    $col = sprintf ( "%.0f", $col ); 
		}
	    }

            push( @cols, qq{<td class="tableRow" nowrap="nowrap">$col</td>} );
        }
        push( @rows, "<tr>" . join('',@cols) . "</tr>\n" );
    }

    ###########################################################################
    # If we didn't get any data, make note of that.
    ###########################################################################
    if (scalar( @{$data} ) == 0)
    {
        my $nodata = qq{<tr><td colspan="$numcols">No data was found for this report in the selected time frame.</td></tr>};
        push( @rows, $nodata );
    }
    ###########################################################################
    # OR.. if we were given an HREF to show "more", link that in.
    ###########################################################################
    elsif ($HREF)
    {
        my $more = qq{<tr><td colspan="$numcols">Click <a href="$HREF">here</a> for the full report.</td></tr>};
        push( @rows, $more );
    }

    ###########################################################################
    # Build up the whole HTML table, and return it back to the caller.
    ###########################################################################
    my $t_open  = qq{<table border="0" cellpadding="2" cellspacing="1" width="100%">};
    my $t_close = qq{</table>};
    return $t_open . join('',@rows) . $t_close;
}

1;
